void tesMellinCov(){
  using namespace RooFit;
 
  RooRealVar *t  = new RooRealVar( "t", "proper time", -1.0 , 5.0 , "ps" );
  RooRealVar *st = new RooRealVar("st", "proper time resolution",  0.,  0.08, "ps" );
  RooRealVar *k  = new RooRealVar( "k", "k factor",  0.3 ,  1.8  );

  // observables 
  RooArgSet* observables = new RooArgSet(*t,*st);
  
  // read in data
  RooDataSet *tData = RooDataSet::read("lifetimeData.txt", RooArgSet( *observables ) );
  RooDataSet *kData = RooDataSet::read("kFactorData.txt" , RooArgSet( *k ) );

  // check the reading in
  TCanvas *MyCan = new TCanvas();

  RooPlot *tframe = t->frame();
  tData->plotOn(tframe);
  tframe->Draw();
  MyCan->Print("tData.eps"); 

  RooPlot *kframe = k->frame();
  kData->plotOn(kframe);
  kframe->Draw();
  MyCan->Print("kData.eps");

  //
  RooRealVar *Tau = new RooRealVar("Tau", "lifetime", 1.5, 0.1, 3.0, "ps");
   
  RooRealVar *TauResScale     = new RooRealVar("TauResScale","resolutions scale",1.185, 0.5, 3);
  RooRealVar *TauResBias      = new RooRealVar("TauResBias","bias",0.,-5,5);
  RooRealVar *TauResBiasScale = new RooRealVar("TauResBiasScale","bias scale",1.0,0.5,3);
  RooResolutionModel *TauRes = new RooGaussModel("TauRes","resolution model",
                     *t,*TauResBias,*st,*TauResBiasScale,*TauResScale);
  // Exp(t|tau) fConv Gau(st)   --- fConv: Fourier convolution
  RooAbsPdf  *TauPdf = new RooDecay("BcTauPdf", "proper time pdf", *t, *Tau, *TauRes,RooDecay::SingleSided);

  TauResBias->setConstant(kTRUE);
  TauResBiasScale->setConstant(kTRUE);

  // Take into account K factor
  RooFormulaVar *PseudoTau = new RooFormulaVar("PseudoTau", "pseudo lifetime", "k*Tau", RooArgSet(*k,*Tau)); 
  RooAbsPdf  *PseudoTauPdf = new RooDecay("PseudoTauPdf", "proper time pdf", *t, *PseudoTau, *TauRes, RooDecay::SingleSided);

  // K factor distribution, one Gaussian
  // RooRealVar *gauMean  = new RooRealVar( "gauMean" , "mean" , 1.0, 0.8, 1.2 );
  // RooRealVar *gauSigma = new RooRealVar( "gauSigma", "sigma", 0.2, 0.1, 0.3 );
  // RooAbsPdf *kPdf = new RooGaussian("kPdf", "k distribution", *k, *gauMean, *gauSigma) ;

  RooDataHist *kHist = new RooDataHist("kHist","kHist",*k,*kData);
  RooHistPdf  *kPdf  = new RooHistPdf("kPdf","kPdf",*k,*kHist);

  // RooKeysPdf doesn't work
  //RooAbsPdf *kPdf = new RooKeysPdf( "kPdf", "kPdf", *k, *kdata ); 

  // [ Exp(t|k*tau) fConv Gau(st)] mConv Gau(k)  --- mConv: Mellin convolution, k integrated out
  k->setBins(10000,"cache") ;
  RooAbsPdf *PseudoPdf = new RooFFTConvPdf("PseudoPdf", "PseudoPdf", *k, *PseudoTauPdf, *kPdf );

  RooPlot *tframe = t->frame();
  PseudoPdf->plotOn(tframe);
  tframe->Draw();

  PseudoPdf->fitTo(*tData);
}
